#include "exErrors.h"

#include <stdint.h>
#include <stdbool.h>
#include <string.h>

#if defined(_WIN32) && !defined(_CVI_)
#define INLINE __inline
#else
#define INLINE inline
#endif

#ifdef __cplusplus
extern "C" {
#endif

 //!
 //! @file
 //!
 //! Common error codes.
 //!

#ifndef _CommonErrors_H
#define _CommonErrors_H

 //! Specific Driver Exception error. 
 //! This is a single error which indicates at the COM/lib layer that a driver/firmware error occurred.
 //! DO NOT EDIT the below error code.

#define IVI_E_SPECIFIC_DRIVER_EXCEPTION 0x80044002

 //! IVI errors.
#define IVI_E_BASE 0x80047000

#define IVI_E_CANNOT_RECOVER 0x80047000
#define IVI_E_INSTRUMENT_STATUS 0x80047001
#define IVI_E_CANNOT_OPEN_FILE 0x80047002
#define IVI_E_READING_FILE 0x80047003
#define IVI_E_WRITING_FILE 0x80047004
#define IVI_E_INVALID_PATHNAME 0x8004700b
#define IVI_E_INVALID_VALUE 0x80047010
 //! FUNCTION and METHOD are the same code
#define IVI_E_FUNCTION_NOT_SUPPORTED 0x80047011
#define IVI_E_METHOD_NOT_SUPPORTED 0x80047011
 //! PROPERTY and ATTRIBUTE are the same code
#define IVI_E_ATTRIBUTE_NOT_SUPPORTED 0x80047012
#define IVI_E_PROPERTY_NOT_SUPPORTED 0x80047012
#define IVI_E_VALUE_NOT_SUPPORTED 0x80047013
#define IVI_E_NOT_INITIALIZED 0x8004701d
#define IVI_E_UNKNOWN_CHANNEL_NAME 0x80047020
#define IVI_E_TOO_MANY_OPEN_FILES 0x80047023
#define IVI_E_CHANNEL_NAME_REQUIRED 0x80047044
#define IVI_E_MISSING_OPTION_NAME 0x80047049
#define IVI_E_MISSING_OPTION_VALUE 0x8004704a
#define IVI_E_BAD_OPTION_NAME 0x8004704b
#define IVI_E_BAD_OPTION_VALUE 0x8004704c
#define IVI_E_OUT_OF_MEMORY 0x80047056
#define IVI_E_OPERATION_PENDING 0x80047057
#define IVI_E_NULL_POINTER 0x80047058
#define IVI_E_UNEXPECTED_RESPONSE 0x80047059
#define IVI_E_FILE_NOT_FOUND 0x8004705b
#define IVI_E_INVALID_FILE_FORMAT 0x8004705c
#define IVI_E_STATUS_NOT_AVAILABLE 0x8004705d
#define IVI_E_ID_QUERY_FAILED 0x8004705e
#define IVI_E_RESET_FAILED 0x8004705f
#define IVI_E_RESOURCE_UNKNOWN 0x80047060
#define IVI_E_ALREADY_INITIALIZED 0x80047061
#define IVI_E_CANNOT_CHANGE_SIMULATION_STATE 0x80047062
#define IVI_E_INVALID_NUMBER_OF_LEVELS_IN_SELECTOR 0x80047063
#define IVI_E_INVALID_RANGE_IN_SELECTOR 0x80047064
#define IVI_E_UNKOWN_NAME_IN_SELECTOR 0x80047065
#define IVI_E_UNKNOWN_NAME_IN_SELECTOR 0x80047065
#define IVI_E_BADLY_FORMED_SELECTOR 0x80047066
#define IVI_E_UNKNOWN_PHYSICAL_IDENTIFIER 0x80047067

 //! These are broken, should be VTEX_E_(blah)
 // IVI Warnings
#define IVI_W_BASE 0x47000

#define IVI_W_NSUP_ID_QUERY 0x47065
#define IVI_W_NSUP_RESET 0x47066
#define IVI_W_NSUP_SELF_TEST 0x47067
#define IVI_W_NSUP_ERROR_QUERY 0x47068
#define IVI_W_NSUP_REV_QUERY 0x47069

 //
 // Do not edit IVI class compliant errors.  Add custom errors below
 //

 //! Driver errors.
#define VTEX_E_BASE 0xffff4000

#define VTEX_E_CAN_NOT_GET_A_WRITE_ONLY_PROPERTY 0xffff4001
#define VTEX_E_PROPERTY_TEMPLATE_NOT_INITIALIZED_PROPERLY 0xffff4002
#define VTEX_E_UNKNOWN_ERROR 0xffff4003
#define VTEX_E_MODULES_FROM_DIFFERENT_IP_ADDRESS 0xffff4004
#define VTEX_E_UNKNOWN_MODULE_TYPE 0xffff4005
#define VTEX_E_MULTIPLE_MODULES_SPECIFIED_IN_SAME_SLOT 0xffff4006
#define VTEX_E_CAN_NOT_CONNECT_TO_SLOT_0 0xffff4007
#define VTEX_E_SPECIFIED_MODULE_DOES_NOT_EXIST_AT_SPECIFIED_SLOT 0xffff4008
#define VTEX_E_UNABLE_TO_OPEN_LOG_FILE 0xffff4009
#define VTEX_E_INVALID_LOG_FILE_ACCESS_MODE 0xffff400a
#define VTEX_E_UNABLE_TO_CONNECT_TO_INSTRUMENT 0xffff400b
#define VTEX_E_LOG_FILE_ALREADY_OPEN 0xffff400c
#define VTEX_E_CAN_NOT_SET_A_READ_ONLY_PROPERTY 0xffff400d
#define VTEX_E_INTERNAL_NULL_POINTER 0xffff400e
#define VTEX_E_NOT_IMPLEMENTED 0xffff400f
#define VTEX_E_SIMULATING_WITH_NO_SLOTS_SPECIFIED 0xffff4010
#define VTEX_E_SIMULATION_NO_ENVIRONMENT_VAR 0xffff4011
#define VTEX_E_LOG_FILE_NOT_OPEN 0xffff4012
#define VTEX_E_LOGGING_MODE_FALSE 0xffff4013
#define VTEX_E_INCORRECT_MODULE_TYPE_IN_DCF 0xffff4014
#define VTEX_E_DCF_MALFORMED 0xffff4015
#define VTEX_E_DCF_AVAILABLE 0xffff4016
#define VTEX_E_DCF_UNKNOWN_VERSION 0xffff4017
#define VTEX_E_WRONG_MODE 0xffff4018
#define VTEX_E_MODULE_NOT_FOUND 0xffff4019
#define VTEX_E_CONFIG_INTERNAL_INCONSISTENCY 0xffff401a
#define VTEX_E_NOT_SUPPORT_IN_SIMULATION 0xffff401b
#define VTEX_E_INVALID_CONFIG_NAME 0xffff401c

#define VTEX_E_VIRTUAL_INSTRUMENT_NOT_CONSISTENT 0xffff401d
 //! Errors ported from CommonErrors.ex

#define VTEX_E_IO_GENERAL 0xffff401e
#define VTEX_E_IO_TIMEOUT 0xffff401f
#define VTEX_E_MODEL_NOT_SUPPORTED 0xffff4020
#define VTEX_E_WRAPPED_DRIVER_ERROR 0xffff4021
#define VTEX_E_NO_IVI_REPRESENTATION 0xffff4022
#define VTEX_E_SPECIFIC_DRIVER_EXCEPTION 0xffff4023
#define VTEX_E_NO_MODULES_INITIALIZED 0xffff4024
#define VTEX_E_TRIGGERS_NOT_CONSISTENT 0xffff4025
#define VTEX_E_TRIGGER_IN_USE 0xffff4026
#define VTEX_E_TRIGGER_NEEDED 0xffff4027
#define VTEX_E_DRIVER_ERROR_QUEUE_FULL 0xffff4028
#define VTEX_E_TOO_MANY_SLOTS 0xffff4029
#define VTEX_E_ADDRESS_TOO_LONG 0xffff402a


 //! Driver warnings.
#define VTEX_W_BASE 0x7fff4000
#define VTEX_W_NET_CLOSURE 0x7fff4001
#define VTEX_W_MORE_DATA_AVAILABLE 0x7fff4002

 //! Device errors.
#define FWPLATFORM_E_BASE 0x80008000

#define FWPLATFORM_E_NEED_INIT 0x80008001
#define FWPLATFORM_E_INTERNAL 0x80008002
#define FWPLATFORM_E_INVALID 0x80008003
#define FWPLATFORM_E_TIMEOUT 0x80008004
#define FWPLATFORM_E_NO_MEM 0x80008005
#define FWPLATFORM_E_FILE 0x80008006
#define FWPLATFORM_E_BLOCKED 0x80008007
#define FWPLATFORM_E_SUBPROCESS 0x80008008
#define FWPLATFORM_E_EMPTY 0x80008009
#define FWPLATFORM_E_IO 0x8000800a
#define FWPLATFORM_E_BUSY 0x8000800b
#define FWPLATFORM_E_INIT_ALREADY 0x8000800c
#define FWPLATFORM_E_FULL 0x8000800d
#define FWPLATFORM_E_UNSUPPORTED 0x8000800e
#define FWPLATFORM_E_FORMAT 0x8000800f
#define FWPLATFORM_E_IO_DATA 0x80008010
#define FWPLATFORM_E_IO_TIMEOUT 0x80008011
#define FWPLATFORM_E_BLOCK_IO_TIMEOUT 0x80008012
#define FWPLATFORM_E_SYNC 0x80008013
#define FWPLATFORM_E_NOT_READY 0x80008014

 //! Device warnings.
#define FWPLATFORM_W_BASE 0x8000

#endif /* ! _CommonErrors_H */

#ifdef  __cplusplus
}
#endif

