#include "exErrors.h"

#include <stdint.h>
#include <stdbool.h>
#include <string.h>

#if defined(_WIN32) && !defined(_CVI_)
#define INLINE __inline
#else
#define INLINE inline
#endif

#ifdef __cplusplus
extern "C" {
#endif

 //!
 //! @file
 //!
 //! Switch error codes.
 //!

#ifndef _SwitchErrors_H
#define _SwitchErrors_H

 //! IVI switch errors.
#define IVISWTCH_E_BASE 0x80010000

#define IVISWTCH_E_TRIGGER_NOT_SOFTWARE 0x80010001
#define IVISWTCH_E_INVALID_SCAN_LIST 0x80010002
#define IVISWTCH_E_RSRC_IN_USE 0x80010003
#define IVISWTCH_E_EMPTY_SCAN_LIST 0x80010004
#define IVISWTCH_E_EMPTY_SWITCH_PATH 0x80010005
#define IVISWTCH_E_SCAN_IN_PROGRESS 0x80010006
#define IVISWTCH_E_NO_SCAN_IN_PROGRESS 0x80010007
#define IVISWTCH_E_NO_SUCH_PATH 0x80010008
#define IVISWTCH_E_IS_CONFIGURATION_CHANNEL 0x80010009
#define IVISWTCH_E_INVALID_SWITCH_PATH 0x8001000a
#define IVISWTCH_E_PATH_NOT_FOUND 0x8001000b
#define IVISWTCH_E_DISCONTINUOUS_PATH 0x8001000c
#define IVISWTCH_E_CANNOT_CONNECT_DIRECTLY 0x8001000d
#define IVISWTCH_E_CHANNELS_ALREADY_CONNECTED 0x8001000e
#define IVISWTCH_E_CANNOT_CONNECT_TO_ITSELF 0x8001000f
#define IVISWTCH_E_NOT_A_CONFIGURATION_CHANNEL 0x80010010
#define IVISWTCH_E_ATTEMPT_TO_CONNECT_SOURCES 0x80010011
#define IVISWTCH_E_EXPLICIT_CONNECTION_EXISTS 0x80010012
#define IVISWTCH_E_LEG_MISSING_FIRST_CHANNEL 0x80010013
#define IVISWTCH_E_LEG_MISSING_SECOND_CHANNEL 0x80010014
#define IVISWTCH_E_CHANNEL_DUPLICATED_IN_LEG 0x80010015
#define IVISWTCH_E_CHANNEL_DUPLICATED_IN_PATH 0x80010016
#define IVISWTCH_E_MAX_TIME_EXCEEDED 0x80010017

 //! IVI switch warnings.
#define IVISWTCH_W_BASE 0x10000

#define IVISWTCH_W_PATH_REMAINS 0x10001
#define IVISWTCH_W_IMPLICIT_CONNECTION_EXISTS 0x10002

 // 
 // Do not edit IVI class compliant errors.  Add custom errors below.
 //

 //! Driver errors.
#define VTEXSWITCH_E_BASE 0x80014000

#define VTEXSWITCH_E_CHANNELS_ARE_FROM_DIFFERENT_PLUGIN_MODULES 0x80014001
#define VTEXSWITCH_E_SETPATH_DISCONTINUOUS_PATH 0x80014002
#define VTEXSWITCH_E_SLOTNUMBER_NOT_FOUND_IN_TABLE 0x80014003
#define VTEXSWITCH_E_INTERNAL_ERROR_WHILE_PROCESSING_SCANLIST 0x80014004
#define VTEXSWITCH_E_CHANNEL_NOT_A_SOURCE_CHANNEL 0x80014005
#define VTEXSWITCH_E_CHANNEL_ONE_UNKNOWN 0x80014006
#define VTEXSWITCH_E_CHANNEL_TWO_UNKNOWN 0x80014007
#define VTEXSWITCH_E_RELAY_CURRENTLY_IN_USE 0x80014008
#define VTEXSWITCH_E_CANNOT_DISCONNECT_ITSELF 0x80014009
#define VTEXSWITCH_E_INVALID_COILVALUE 0x8001400a
 // removed error code VTEXSWITCH_E_EXCLUDE_LIST_ALREADY_ADDED
#define VTEXSWITCH_E_UNKNOWN_EXCLUDE_LIST 0x8001400c
#define VTEXSWITCH_E_DUPLICATE_EXCLUDE_LIST_NAME 0x8001400d
#define VTEXSWITCH_E_EXCLUDE_LIST_VIOLATED 0x8001400e
 // removed error code VTEXSWITCH_E_INVALID_EXCLUDE_LIST
#define VTEXSWITCH_E_INTERNAL_DRIVER_DATASTRUCTURE_CORRUPTION 0x80014010
#define VTEXSWITCH_E_RESOURCE_CONFLICT_EXISTS 0x80014011
#define VTEXSWITCH_E_INVALID_SWITCH_PATH 0x80014012
#define VTEXSWITCH_E_INVALID_BOOLEAN_VALUE 0x80014013
#define VTEXSWITCH_E_COMMUNICATION_ERROR_WITH_INSTRUMENT 0x80014014
#define VTEXSWITCH_E_ERROR_PARSING_SWITCH_PATH_STRING 0x80014015
#define VTEXSWITCH_E_CHANNEL_WIRE_MODES_MISMATCH 0x80014016
#define VTEXSWITCH_E_UNKNOWN_RELAY 0x80014017
#define VTEXSWITCH_E_SOURCE_CHANNELS_LIST_VIOLATED 0x80014018
#define VTEXSWITCH_E_INVALID_RELAY_TO_TOGGLE 0x80014019
#define VTEXSWITCH_E_FPGA_READBACK_MISMATCH 0x8001401a
#define VTEXSWITCH_E_UNKNOWN_BIT_PATTERN 0x8001401b
#define VTEXSWITCH_E_INVALID_RELAY_TO_QUERY 0x8001401c
#define VTEXSWITCH_E_QUERYING_ODOMETER_OF_MULTICOIL_RELAY 0x8001401d
#define VTEXSWITCH_E_RELAY_IN_SCANLIST_CANT_PERFORM_MBB 0x8001401e


 //! Driver warnings.
#define VTEXSWITCH_W_BASE 0x14000

#define VTEXSWITCH_W_CHANNEL_ALREADY_SPECIFIED_AS_A_SOURCE_CHANNEL 0x14001
#define VTEXSWITCH_W_IMPLICIT_CONNECTION_EXISTS 0x14002
#define VTEXSWITCH_W_EXTERNAL_CONNECTION_DOES_NOT_EXIST 0x14003

 //! Device errors.
#define FWSWITCH_E_BASE 0x80018000

#define FWSWITCH_E_PARM_LEN_MISMATCH 0x80018001
#define FWSWITCH_E_FPGA_IO 0x80018002
#define FWSWITCH_E_INVALID_SCAN_DELAY 0x80018003
#define FWSWITCH_E_INVALID_SCAN_MODE 0x80018004
#define FWSWITCH_E_INVALID_TRIG_SOURCE 0x80018005
#define FWSWITCH_E_INVALID_RELAY_IDX 0x80018006
#define FWSWITCH_E_INVALID_ODOMETER_SRC 0x80018007
#define FWSWITCH_E_INVALID_ARRAY_LEN 0x80018008
#define FWSWITCH_E_INVALID_COIL_BITMAP_OFFSET 0x80018009
#define FWSWITCH_E_INVALID_ODOMETER_LEN_IN_FLASH 0x8001800a
#define FWSWITCH_E_INVALID_SCANLIST_SIZE 0x8001800b
#define FWSWITCH_E_SCANLIST_EXCEEDS_BUF 0x8001800c
#define FWSWITCH_E_INVALID_TIMEOUT 0x8001800d
#define FWSWITCH_E_FLASH_FILE_OPERATION_FAILED 0x8001800e
#define FWSWITCH_E_FPGA_INTERNAL_ERROR 0x8001800f
#define FWSWITCH_E_FUNCTIONALITY_NOT_AVAILABLE 0x80018010
#define FWSWITCH_E_MEM_ALLOC_FAILED 0x80018011
#define FWSWITCH_E_FAILED_TO_OPEN_SCANNER_DEVICE 0x80018012
#define FWSWITCH_E_NULL_POINTER_ARGUMENT 0x80018013
#define FWSWITCH_E_NULL_PRIVATE_SLOT_DATA 0x80018014
#define FWSWITCH_E_INVALID_MODULE_IN_SLOT 0x80018015
#define FWSWITCH_E_STATE_MISMATCH_DRIVEN_STATE 0x80018016
#define FWSWITCH_E_STATE_MISMATCH_READBACK_STATE 0x80018017
#define FWSWITCH_E_INVALID_BOARD_INDEX 0x80018018
#define FWSWITCH_E_INVALID_FRAM_OFFSET 0x80018019
#define FWSWITCH_E_INVALID_SAVED_STATE_INDEX 0x8001801a
#define FWSWITCH_E_SAVED_STATE_INDEX_UNDEFINED 0x8001801b
#define FWSWITCH_E_RDB_NOT_INSTALLED 0x8001801c
#define FWSWITCH_E_RELAY_FAILURE 0x8001801d
#define FWSWITCH_E_READ_WHILE_RELAY_SETTLING_IN_PHASE2 0x8001801e
#define FWSWITCH_E_FPGA_ERROR_UNKNOWN 0x8001801f
#define FWSWITCH_E_SCANBUFFER_WRITE_ERROR 0x80018020
#define FWSWITCH_E_SCANNER_FAILURE 0x80018021
#define FWSWITCH_E_INVALID_TRIGGER 0x80018022
#define FWSWITCH_E_OTHER_CMDS_WHILE_RELAY_WRITE_IN_PROGRESS 0x80018023
#define FWSWITCH_E_WRONG_CMDS_FOR_PIO_OPS 0x80018024
#define FWSWITCH_E_FRONT_PANEL_OPEN_SIGNAL_ACTIVE 0x80018025

 //! Device warnings.
#define FWSWITCH_W_BASE 0x18000


#endif /* ! _SwitchErrors_H */

#ifdef  __cplusplus
}
#endif

