/******************************************************************************
 *
 *  .----------------------.
 *  |==     ==  ======  == |
 *  | ==   ==   ======  == |
 *  |  == ==      ==    == |
 *  |   ===       ==    == |
 *  |    =        ==    == |
 *  '----------------------'
 *
 * $Id: libSwitch.h 23806 2013-11-11 11:48:18Z srikanthk $
 *
 * Copyright 2006-9 VTI Instrument Corporation as an unpublished work. All
 * rights reserved. The information contained herein is confidential property
 * of VTI Instrument Corporation. Use, copy, transfer or disclosure of such
 * information is prohibited except by express written agreement with VTI
 * Instrument Corporation.
 *
 * PURPOSE: 
 *   Class definition of the main LibSwitch class
 *
 ******************************************************************************/

#ifndef _LIB_SWITCH_H
#define _LIB_SWITCH_H

#include <vector>

#include "vtexapi.h"
#include "vtexException.h"
#include "libInherent.h"

#ifndef _ATL_ATTRIBUTES
#include "SwitchConstants.h"
#endif

#include "CommonErrors.h"
#include "SwitchErrors.h"


class VTEX_API LibSwitchParallelIO
{
    public:
        virtual ~LibSwitchParallelIO();

        //Datamembers
        property <LibSwitchParallelIO, int32_t, READ_WRITE> OutputEnableMask;
        property <LibSwitchParallelIO, int32_t, READ_WRITE> Data;

        //Methods
        virtual VTEXResult put_OutputEnableMask(int32_t value) = 0;
        virtual VTEXResult get_OutputEnableMask(int32_t* value) = 0;
        virtual VTEXResult put_Data(int32_t value) = 0;
        virtual VTEXResult get_Data(int32_t* value) = 0;
};


class VTEX_API LibSwitchParallelIOs
{
    public:
        virtual ~LibSwitchParallelIOs();

        //Datamembers
        property <LibSwitchParallelIOs, int, READ_ONLY> Count;
        arrayizer <LibSwitchParallelIOs, LibSwitchParallelIO*, const VTEXString&> Item;
        arrayizer <LibSwitchParallelIOs, VTEXString, int> Name;

        //Methods
        virtual LibSwitchParallelIO* get_Item(const VTEXString& portName) = 0;
        virtual VTEXString get_Name(int repCapIndex) = 0;
        virtual VTEXResult get_Count(int* count) = 0;
};


class VTEX_API LibSwitchChannelCharacteristics
{
    public:
        virtual ~LibSwitchChannelCharacteristics();

        //Attributes
        property <LibSwitchChannelCharacteristics, double, READ_ONLY> ACCurrentCarryMax;
        property <LibSwitchChannelCharacteristics, double, READ_ONLY> ACCurrentSwitchingMax;
        property <LibSwitchChannelCharacteristics, double, READ_ONLY> ACPowerCarryMax;
        property <LibSwitchChannelCharacteristics, double, READ_ONLY> ACPowerSwitchingMax;
        property <LibSwitchChannelCharacteristics, double, READ_ONLY> ACVoltageMax;
        property <LibSwitchChannelCharacteristics, double, READ_ONLY> Bandwidth;
        property <LibSwitchChannelCharacteristics, double, READ_ONLY> Impedance;
        property <LibSwitchChannelCharacteristics, double, READ_ONLY> DCCurrentCarryMax;
        property <LibSwitchChannelCharacteristics, double, READ_ONLY> DCCurrentSwitchingMax;
        property <LibSwitchChannelCharacteristics, double, READ_ONLY> DCPowerCarryMax;
        property <LibSwitchChannelCharacteristics, double, READ_ONLY> DCPowerSwitchingMax;
        property <LibSwitchChannelCharacteristics, double, READ_ONLY> DCVoltageMax;
        property <LibSwitchChannelCharacteristics, double, READ_ONLY> SettlingTime;
        property <LibSwitchChannelCharacteristics, int32_t, READ_ONLY> WireMode;

        //Methods
        virtual VTEXResult get_ACCurrentCarryMax(double *value) = 0;
        virtual VTEXResult get_ACCurrentSwitchingMax(double *value) = 0;
        virtual VTEXResult get_ACPowerCarryMax(double *value) = 0;
        virtual VTEXResult get_ACPowerSwitchingMax(double *value) = 0;
        virtual VTEXResult get_ACVoltageMax(double *value) = 0;
        virtual VTEXResult get_Bandwidth(double *value) = 0;
        virtual VTEXResult get_Impedance(double *value) = 0;
        virtual VTEXResult get_DCCurrentCarryMax(double *value) = 0;
        virtual VTEXResult get_DCCurrentSwitchingMax(double *value) = 0;
        virtual VTEXResult get_DCPowerCarryMax(double *value) = 0;
        virtual VTEXResult get_DCPowerSwitchingMax(double *value) = 0;
        virtual VTEXResult get_DCVoltageMax(double *value) = 0;
        virtual VTEXResult get_SettlingTime(double *value) = 0;
        virtual VTEXResult get_WireMode(int32_t *value) = 0;
};


class VTEX_API LibSwitchChannel
{
    public:
        virtual ~LibSwitchChannel();

        //Attributes
        LibSwitchChannelCharacteristics* Characteristics;        

        property <LibSwitchChannel, bool, READ_WRITE> IsConfigurationChannel;
        property <LibSwitchChannel, bool, READ_WRITE> IsSourceChannel;

        //Methods
        virtual VTEXResult put_IsConfigurationChannel(bool value) = 0;
        virtual VTEXResult get_IsConfigurationChannel(bool* value) = 0;
        virtual VTEXResult put_IsSourceChannel(bool value) = 0;
        virtual VTEXResult get_IsSourceChannel(bool* value) = 0;
};


class VTEX_API LibSwitchChannels
{
    public:
        virtual ~LibSwitchChannels();

        //Attributes
        property <LibSwitchChannels, int, READ_ONLY> Count;
        arrayizer <LibSwitchChannels, LibSwitchChannel*, const VTEXString&> Item;
        arrayizer <LibSwitchChannels, VTEXString, int> Name;

        //Methods
        virtual LibSwitchChannel* get_Item(const VTEXString& channelName) = 0;
        virtual VTEXString get_Name(int repCapIndex) = 0;
        virtual VTEXResult get_Count(int* count) = 0;
};


class VTEX_API LibSwitchAttenuator
{
    public:
        virtual ~LibSwitchAttenuator();

        //Attributes
        property <LibSwitchAttenuator, double, READ_WRITE> Setting;

        //Methods
        virtual VTEXResult put_Setting(double value) = 0;
        virtual VTEXResult get_Setting(double* value) = 0;
};


class VTEX_API LibSwitchAttenuators
{
    public:
        virtual ~LibSwitchAttenuators();

        //Attributes
        property <LibSwitchAttenuators, int, READ_ONLY> Count;
        arrayizer <LibSwitchAttenuators, LibSwitchAttenuator*, const VTEXString&> Item;
        arrayizer <LibSwitchAttenuators, VTEXString, int> Name;

        //Methods
        virtual LibSwitchAttenuator* get_Item(const VTEXString& name) = 0;
        virtual VTEXString get_Name(int repCapIndex) = 0;
        virtual VTEXResult get_Count(int* count) = 0;
};


class VTEX_API LibSwitchInstrumentSpecific
{
    public:
        virtual ~LibSwitchInstrumentSpecific();
        
        LibSwitchParallelIOs* ParallelIOs;
        LibSwitchAttenuators* Attenuators;

        //Attributes
        property <LibSwitchInstrumentSpecific, VTEXString, READ_ONLY> SerialNumber; 
        property <LibSwitchInstrumentSpecific, VTEXString, READ_ONLY> ListOfRelays; 
        property <LibSwitchInstrumentSpecific, VTEXString, READ_ONLY> ListOfChannels; 
        property <LibSwitchInstrumentSpecific, VTEXString, READ_ONLY> ListOfAttenuators; 
        property <LibSwitchInstrumentSpecific, VTEXString, READ_ONLY> ListOfParallelIOs; 
        property <LibSwitchInstrumentSpecific, bool, READ_WRITE> VerifyRelayState; 

        //Methods
        virtual VTEXResult AddPathLevelExcludeList(const VTEXString& excludeList, const VTEXString& name) = 0;
        virtual VTEXResult RemovePathLevelExcludeList(const VTEXString& name) = 0;
        virtual VTEXResult ExternalConnection(const VTEXString& channel1, const VTEXString& channel2) = 0;
        virtual VTEXResult OpenLogFile(const VTEXString& fileName, const VTEXString& accessMode) = 0;
        virtual VTEXResult CloseLogFile() = 0;
        virtual VTEXResult GetOdometers(const VTEXString& relayList, VTEXIntVector& count) = 0;
        virtual VTEXResult LoadState(int32_t id) = 0;

        //Relay-level interfaces
        virtual VTEXResult CloseRelays(const VTEXString& relayList) = 0;
        virtual VTEXResult OpenRelays(const VTEXString& relayList) = 0;
        virtual enum VTEXSwitchRelayStateEnum GetRelayState(const VTEXString& relayName) = 0;
        virtual VTEXResult GetRelayStates(const VTEXString& relayList, VTEXEnumVector(VTEXSwitchRelayStateEnum)& states) = 0;
        virtual VTEXResult AddRelayLevelExcludeList(const VTEXString& excludeList, const VTEXString& name) = 0;
        virtual VTEXResult RemoveRelayLevelExcludeList(const VTEXString& name) = 0;

        virtual VTEXResult get_SerialNumber(VTEXString* val) = 0;
        virtual VTEXResult get_ListOfRelays(VTEXString* val) = 0;
        virtual VTEXResult get_ListOfChannels(VTEXString* val) = 0;
        virtual VTEXResult get_ListOfAttenuators(VTEXString* val) = 0;
        virtual VTEXResult get_ListOfParallelIOs(VTEXString* val) = 0;
        virtual VTEXResult get_VerifyRelayState(bool* verify) = 0;
        virtual VTEXResult put_VerifyRelayState(bool verify) = 0;
};


class VTEX_API LibSwitchScan
{
    public:
        virtual ~LibSwitchScan();

        //Attributes
        property <LibSwitchScan, bool, READ_WRITE> Continuous; 
        property <LibSwitchScan, double, READ_WRITE> Delay;
        property <LibSwitchScan, bool, READ_ONLY> IsScanning;
        property <LibSwitchScan, VTEXString, READ_WRITE> List;
        property <LibSwitchScan, enum VTEXSwitchScanModeEnum, READ_WRITE> Mode;
        property <LibSwitchScan, int32_t, READ_ONLY> NumberOfColumns;
        property <LibSwitchScan, int32_t, READ_ONLY> NumberOfRows;

        property <LibSwitchScan, enum VTEXSwitchTriggerInputEnum, READ_WRITE> Input;
        property <LibSwitchScan, enum VTEXSwitchAdvancedOutputEnum, READ_WRITE> AdvancedOutput; 


        //Methods
        virtual VTEXResult Abort() = 0;

        virtual VTEXResult ConfigureList(const VTEXString& List, enum VTEXSwitchScanModeEnum mode) = 0;
        virtual VTEXResult Initiate() = 0;
        virtual VTEXResult SendSoftwareTrigger() = 0;
        virtual VTEXResult WaitForScanComplete(int32_t MaxTimeMilliseconds) = 0;
        virtual VTEXResult ConfigureTrigger(double ScanDelay, 
                                            enum VTEXSwitchTriggerInputEnum TriggerInput,
                                            enum VTEXSwitchAdvancedOutputEnum AdvancedOutput) = 0;

        virtual VTEXResult get_Continuous(bool *val) = 0;
        virtual VTEXResult put_Continuous(bool val) = 0;
        virtual VTEXResult get_Delay(double *val) = 0;
        virtual VTEXResult put_Delay(double val) = 0;
        virtual VTEXResult get_IsScanning(bool *val) = 0;
        virtual VTEXResult get_List(VTEXString *val) = 0;
        virtual VTEXResult put_List(const VTEXString &val) = 0;
        virtual VTEXResult get_Mode(VTEXSwitchScanModeEnum* val) = 0;
        virtual VTEXResult put_Mode(VTEXSwitchScanModeEnum val) = 0;
        virtual VTEXResult get_NumberOfColumns(int32_t *val) = 0;
        virtual VTEXResult get_NumberOfRows(int32_t *val) = 0;

        virtual VTEXResult get_Input(VTEXSwitchTriggerInputEnum* val) = 0;
        virtual VTEXResult put_Input(VTEXSwitchTriggerInputEnum val) = 0;
        virtual VTEXResult get_AdvancedOutput(VTEXSwitchAdvancedOutputEnum* val) = 0;
        virtual VTEXResult put_AdvancedOutput(VTEXSwitchAdvancedOutputEnum val) = 0;
};


class VTEX_API LibSwitchPath
{
    public:
        virtual ~LibSwitchPath();

        //Attributes
        property <LibSwitchPath, bool, READ_ONLY> IsDebounced; 

        //Methods
        virtual enum VTEXSwitchPathCapabilityEnum CanConnect(const VTEXString& channel1, const VTEXString& channel2) = 0;
        virtual VTEXResult Connect(const VTEXString& channel1, const VTEXString& channel2) = 0;
        virtual VTEXResult Disconnect(const VTEXString& channel1, const VTEXString& channel2) = 0;
        virtual VTEXResult DisconnectAll() = 0;
        virtual VTEXString GetPath(const VTEXString& channel1, const VTEXString& channel2) = 0;
        virtual VTEXResult SetPath(const VTEXString& pathString) = 0;
        virtual VTEXResult WaitForDebounce(int maxTimeMilliSeconds) = 0;
        virtual VTEXResult get_IsDebounced(bool *val) = 0;
};


class VTEX_API LibSwitch : public LibInherent
{
    public:
        static LibSwitch* Create();
        virtual ~LibSwitch();        
        //Attributes
        //Inherent capabilitites
        property <LibSwitch, bool, READ_ONLY> Initialized;
        LibInherentCapabilityUtility* Utility;
        LibInherentCapabilityDriverOperation* DriverOperation;
        LibInherentCapabilityIdentity* Identity;

        LibSwitchChannels* Channels;
        LibSwitchPath* Path;
        LibSwitchScan* Scan;
        LibSwitchInstrumentSpecific* InstrumentSpecific;
};

#endif  //_LIB_SWITCH_H
