#include "fifo.h"
#include <exception>

FifoReader::FifoReader(UtilsContainer* utils, int32_t max_timeout, VTEXResult timeout_error_code)
{
  m_utils = utils;
  timeout_error = timeout_error_code;
  m_timeout = max_timeout;
  
  //This timeout should never be more than 3X EXP's default timeout
  new_exp_timeout.sec = (max_timeout/1000)+5;
  new_exp_timeout.nsec = 0;
}

VTEXResult FifoReader::FifoRead(int32_t sampleCount, int32_t MaxTimeMilliseconds)
{
  int32_t tempSample = 0;
  int32_t tempTimeout = 0;
  VTEXResult status = IVI_SUCCESS;
  struct exTime oldTimeout = {0,0};

  if(sampleCount == -1)
  {
    status = GetFifoCount(&tempSample);
    if(tempSample != 0)
    {
      sampleCount = tempSample;
    }
  }

  status = m_utils->expManager->getTimeout(&oldTimeout.sec, &oldTimeout.nsec);
  if(status < IVI_SUCCESS)
  {
    return status;
  }

  status = m_utils->expManager->setTimeout(new_exp_timeout.sec, new_exp_timeout.nsec);
  if(status < IVI_SUCCESS)
  {
    return status;
  }
 
  do  
  {
    //Set to max timeout if MTM is -1 
    tempTimeout = (MaxTimeMilliseconds > m_timeout || MaxTimeMilliseconds == -1) ? m_timeout : MaxTimeMilliseconds;

    //NOTE: GetData shouldn't call ReportError, it should just return a status
    status = GetData(sampleCount, tempTimeout, &tempSample);
    if(status >= IVI_SUCCESS) //Exception on error turned off again
    {
      sampleCount -= tempSample;
    }
    else //We got some sort of error condition
    {
      if(status == timeout_error)
      {
        if(MaxTimeMilliseconds > 0)
        {
          MaxTimeMilliseconds -= tempTimeout;
        }
        if(MaxTimeMilliseconds == -1 || MaxTimeMilliseconds > 0)
        {
          status = IVI_SUCCESS;
        }
      }
    }
  }while((sampleCount > 0 || sampleCount==-1) &&   
      status >= IVI_SUCCESS);

  VTEXResult tempStatus = m_utils->expManager->setTimeout(oldTimeout.sec, oldTimeout.nsec);
  //Only set the status if we're not already holding a more important error
  if(status >= IVI_SUCCESS && tempStatus < IVI_SUCCESS)
  {
    status = tempStatus;
  }
  
  return status;
}
