
/******************************************************************************
 *
 *  .----------------------.	
 *  |==     ==  ======  == |	$Author: benf $
 *  | ==   ==   ======  == |	$Revision: 18668 $ 
 *  |  == ==      ==    == |	$Date: 2010-02-19 14:11:48 -0500 (Fri, 19 Feb 2010) $ 
 *  |   ===       ==    == |	$HeadURL: http://orion/svn/nextgen/branches/64Bit_Driver/software/Instrument_drivers/libVTEX/common/impInherent.h $
 *  |    =        ==    == |	
 *  `----------------------'
 *
 * Copyright 2006 VXI Technology Inc. as an unpublished work.
 * All rights reserved. The information contained herein is confidential
 * property of VXI Technology, Inc. Use, copy, transfer or disclosure
 * of such information is prohibited except by express written agreement
 * with VXI Technology, Inc.
 *
 * PURPOSE:
 *   Interface class definition for IVI inherent capabilities
 *
 ******************************************************************************/
#ifndef _IMP_INHERENT_H
#define	_IMP_INHERENT_H


/*******************
 * System header
 *******************/
#include <string>
#include <vector>

/*******************
 * Library header
 *******************/


/*******************
 * Local header
 *******************/
#include "libInherent.h"
#include "utilsContainer.h"

/***********************
 * Forward Declarations
 ***********************/
class UtilsContainer;
class State;

/**********************
*  Macros and Defines *
**********************/
#define VTI_INSTRUMENTS "VTI Instruments Corporation"
#define VTI_DRIVER_DESCRIPTION      "Software driver for VTI instruments"
// Follwoing Macros were originally defined in impDio.h file.

#define VTEX_START() \
  VTEXResult status = m_state->initialized(); \
  if(status < IVI_SUCCESS) \
  { \
    return m_utils->errorManager->ReportError(status); \
  } 

#define SUBMIT(req, resp) \
  { /*Note the extra scope so we can call this macro more than once*/\
    status = sendReq_##req; \
    if(status < IVI_SUCCESS) \
    { \
        return m_utils->errorManager->ReportError(status); \
    } \
    status = recvResp_##resp; \
    if(status < IVI_SUCCESS) \
    { \
      return m_utils->errorManager->ReportError(status); \
    } \
  }

#define SUBMIT_NORETURN(req, resp) \
  { /*Note the extra scope so we can call this macro more than once*/\
    status = sendReq_##req; \
    if(status >= IVI_SUCCESS) \
    { \
        status = recvResp_##resp; \
    } \
  }

#define POINTER_CHECK(ptr) \
  if(ptr == NULL) \
  { \
    status = m_utils->errorManager->queueError(IVI_E_NULL_POINTER, __FUNCTION__, #ptr); \
    return m_utils->errorManager->ReportError(status); \
  }

#define SAFE(call) \
  status = call; \
  if(status < IVI_SUCCESS) \
    return m_utils->errorManager->ReportError(status);

// DEFINE THIS TO PRINT DEBUGGING
//#define COMMON_DEBUG

//Note we left out the ; after printf so you have to call it like: DEBUG(stuff);

#ifdef COMMON_DEBUG
#define LIB_DEBUG(x) (x)
#define LIB_PRINTF(...) printf(__VA_ARGS__)
#else
#define LIB_DEBUG(x)
#endif




class ImpInherent : public LibInherent
{
    public:
        ImpInherent(UtilsContainer *utils = NULL);
        virtual ~ImpInherent();

        virtual VTEXResult Close(); 
        virtual VTEXResult Initialize(const VTEXString& resourceName, 
                                      bool idQuery, 
                                      bool reset, 
                                      const VTEXString& optionString); 

        virtual VTEXResult Initialize(const VTEXString& resourceName, 
                                      bool idQuery, 
                                      bool reset); 

        virtual VTEXResult get_Initialized (bool *val);

    protected:
        UtilsContainer* m_utils;
        State* m_baseState;
        bool m_freeUtils;
		std::vector<Resource> m_resourceList;
		virtual VTEXResult initEXPManager(void);
        virtual VTEXResult init(bool reset) = 0;
        virtual VTEXResult cleanUp() = 0;
};

class ImpInherentCapabilityIdentity : public LibInherentCapabilityIdentity
{ 
    public: 
        ImpInherentCapabilityIdentity(UtilsContainer* utils, State* state);
        virtual ~ImpInherentCapabilityIdentity(); 

        //Methods
        virtual VTEXResult get_Description(VTEXString *val); 
        virtual VTEXResult get_Revision(VTEXString *val); 
        virtual VTEXResult get_Vendor(VTEXString *val); 
        virtual VTEXResult get_GroupCapabilities(VTEXString *val); 
        virtual VTEXResult get_Identifier(VTEXString *val); 
        virtual VTEXResult get_InstrumentFirmwareRevision(VTEXString *val);
        virtual VTEXResult get_InstrumentManufacturer(VTEXString *val); 
        virtual VTEXResult get_InstrumentModel(VTEXString *val);
        virtual VTEXResult get_SpecificationMajorVersion(int32_t *val); 
        virtual VTEXResult get_SpecificationMinorVersion(int32_t *val); 
        virtual VTEXResult get_SupportedInstrumentModels(VTEXString *val);

    protected:
        virtual VTEXString getDescription();
        virtual VTEXString getRevision();
        virtual VTEXString getVendor();
        virtual VTEXString getGroupCapabilities();
        virtual VTEXString getIdentifier();
        virtual VTEXString getInstrumentManufacturer();
        virtual VTEXString getInstrumentModel(VTEXResult* status);
        virtual int32_t getSpecMajorVersion();
        virtual int32_t getSpecMinorVersion();
        virtual VTEXString getSupportedInstruments();


    private:
        UtilsContainer* m_utils;
        State* m_state;
}; 

 
class ImpInherentCapabilityDriverOperation : public LibInherentCapabilityDriverOperation 
{ 
    public: 
        ImpInherentCapabilityDriverOperation(UtilsContainer* utils, State* state);
        virtual ~ImpInherentCapabilityDriverOperation(); 

        //Methods
        virtual VTEXResult ClearInterchangeWarnings(); 
        virtual VTEXResult GetNextCoercionRecord(VTEXString* val); 
        virtual VTEXResult GetNextInterchangeWarning(VTEXString* val); 
        virtual VTEXResult InvalidateAllAttributes(); 
        virtual VTEXResult ResetInterchangeCheck(); 

        virtual VTEXResult get_DriverSetup(VTEXString *val); 
        virtual VTEXResult get_IoResourceDescriptor(VTEXString *val); 
        virtual VTEXResult get_LogicalName(VTEXString *val); 
        virtual VTEXResult get_InterchangeCheck(bool *val); 
        virtual VTEXResult put_InterchangeCheck(bool val); 
        virtual VTEXResult get_Cache(bool *val); 
        virtual VTEXResult put_Cache(bool val); 
        virtual VTEXResult get_QueryInstrumentStatus(bool *val); 
        virtual VTEXResult put_QueryInstrumentStatus(bool val); 
        virtual VTEXResult get_RangeCheck(bool *val); 
        virtual VTEXResult put_RangeCheck(bool val); 
        virtual VTEXResult get_RecordCoercions(bool *val); 
        virtual VTEXResult put_RecordCoercions(bool val); 
        virtual VTEXResult get_Simulate(bool *val); 
        virtual VTEXResult put_Simulate(bool val); 

    private:
        UtilsContainer* m_utils;
        State* m_state;
}; 
 

class ImpInherentCapabilityUtility : public LibInherentCapabilityUtility 
{ 
    public: 
        ImpInherentCapabilityUtility(UtilsContainer* utils, State* state);
        virtual ~ImpInherentCapabilityUtility(); 

        //Methods
        virtual VTEXResult Disable(); 
        virtual VTEXResult ErrorQuery(int32_t *ErrorCode, VTEXString& ErrorMessage); 
        virtual VTEXResult LockObject(); 
        virtual VTEXResult Reset(); 
        virtual VTEXResult ResetWithDefaults(); 
        virtual VTEXResult SelfTest(int32_t *TestResult, VTEXString& TestMessage); 
        virtual VTEXResult UnlockObject(); 

    private:
        UtilsContainer* m_utils;
        State* m_state;
}; 



#if defined(_WIN32) && defined(DLL_EXPORTS)

/* Win32 dynamic link library export */
BSTR STDSTR2BSTR(std::string str);
std::string BSTR2STDSTR(BSTR str);
SAFEARRAY *int_VECT2SAFEARRAY(std::vector<int> vect);
SAFEARRAY *bool_VECT2SAFEARRAY(std::vector<bool> vect);
SAFEARRAY *double_VECT2SAFEARRAY(std::vector<double> vect);

#define VTEX_STRING(x)	STDSTR2BSTR(x)
#define STD_STRING(x)	BSTR2STDSTR(x)
#define VTEX_VECTOR(type,x)	type##_VECT2SAFEARRAY(x)



#else 
/* Linux, Unix,...etc */
#define VTEX_STRING(x)	x
#define STD_STRING(x)	x
#define VTEX_VECTOR(type,x)	x
#endif

#endif  //_IMP_INHERENT_CAPABILITIES_H
