/******************************************************************************
 *
 *  .----------------------.	
 *  |==     ==  ======  == |	$Author: benf $
 *  | ==   ==   ======  == |	$Revision: 20826 $ 
 *  |  == ==      ==    == |	$Date: 2010-08-03 11:18:29 -0700 (Tue, 03 Aug 2010) $ 
 *  |   ===       ==    == |	$HeadURL: http://10.1.0.10/svn/nextgen/branches/Version_3_12_0/software/Instrument_drivers/libVTEX/common/impInherentDriverOperation.cpp $
 *  |    =        ==    == |	
 *  `----------------------'
 *
 * Copyright 2006 VXI Technology Inc. as an unpublished work.
 * All rights reserved. The information contained herein is confidential
 * property of VXI Technology, Inc. Use, copy, transfer or disclosure
 * of such information is prohibited except by express written agreement
 * with VXI Technology, Inc.
 *
 * PURPOSE:
 *   IVI inherent capabilities DriverOperation interface
 *
 ******************************************************************************/


/*******************
 * System header
 *******************/


/*******************
 * Library header
 *******************/


/*******************
 * Local header
 *******************/
#include "utilsContainer.h"
#include "functionLogging.h"
#include "iviOptions.h"
#include "errorManager.h"
#include "impInherent.h"
#include "state.h"


/***********************
 * Forward Declarations
 ***********************/


ImpInherentCapabilityDriverOperation::ImpInherentCapabilityDriverOperation(UtilsContainer* utils, State* state)
{
    m_utils = utils;
    m_state = state;

    DriverSetup.SetAttributes(this,
        &LibInherentCapabilityDriverOperation::get_DriverSetup);
    IoResourceDescriptor.SetAttributes(this,
        &LibInherentCapabilityDriverOperation::get_IoResourceDescriptor);
    LogicalName.SetAttributes(this,
        &LibInherentCapabilityDriverOperation::get_LogicalName);
    InterchangeCheck.SetAttributes(this,
        &LibInherentCapabilityDriverOperation::get_InterchangeCheck,
        &LibInherentCapabilityDriverOperation::put_InterchangeCheck);
    Cache.SetAttributes(this,
        &LibInherentCapabilityDriverOperation::get_Cache,
        &LibInherentCapabilityDriverOperation::put_Cache);
    QueryInstrumentStatus.SetAttributes(this,
        &LibInherentCapabilityDriverOperation::get_QueryInstrumentStatus,
        &LibInherentCapabilityDriverOperation::put_QueryInstrumentStatus);
    RangeCheck.SetAttributes(this,
        &LibInherentCapabilityDriverOperation::get_RangeCheck,
        &LibInherentCapabilityDriverOperation::put_RangeCheck);
    RecordCoercions.SetAttributes(this,
        &LibInherentCapabilityDriverOperation::get_RecordCoercions,
        &LibInherentCapabilityDriverOperation::put_RecordCoercions);
    Simulate.SetAttributes(this,
        &LibInherentCapabilityDriverOperation::get_Simulate,
        &LibInherentCapabilityDriverOperation::put_Simulate);
}


ImpInherentCapabilityDriverOperation::~ImpInherentCapabilityDriverOperation()
{
}


VTEXResult ImpInherentCapabilityDriverOperation::get_DriverSetup(VTEXString *val)
{
    m_utils->log->Log(__FUNCTION__, 0);

    VTEXResult status = m_state->initialized();

    if( (status >= IVI_SUCCESS) && (NULL == val) )
    {
        status = m_utils->errorManager->queueError(IVI_E_NULL_POINTER, __FUNCTION__, "val");
    }
    else if(status >= IVI_SUCCESS)
    {
        *val = VTEX_STRING(m_utils->iviOptions->sDriverSetup);
    }

    return m_utils->errorManager->ReportError(status);
}


VTEXResult ImpInherentCapabilityDriverOperation::get_IoResourceDescriptor(VTEXString *val)
{
    m_utils->log->Log(__FUNCTION__, 0);

    VTEXResult status = m_state->initialized();

    if( (status >= IVI_SUCCESS) && (NULL == val) )
    {
        status = m_utils->errorManager->queueError(IVI_E_NULL_POINTER, __FUNCTION__, "val");
    }
    else if(status >= IVI_SUCCESS)
    {
        *val = VTEX_STRING(m_utils->iviOptions->sIoResourceDescriptor);
    }

    return m_utils->errorManager->ReportError(status);
}


VTEXResult ImpInherentCapabilityDriverOperation::get_QueryInstrumentStatus(bool *val)
{
    m_utils->log->Log(__FUNCTION__, 0);

    VTEXResult status = m_state->initialized();

    if( (status >= IVI_SUCCESS) && (NULL == val) )
    {
        status = m_utils->errorManager->queueError(IVI_E_NULL_POINTER, __FUNCTION__, "val");
    }
    else if(status >= IVI_SUCCESS)
    {
        *val = m_utils->iviOptions->bQueryInstrStatus;
    }

    return m_utils->errorManager->ReportError(status);
}


VTEXResult ImpInherentCapabilityDriverOperation::put_QueryInstrumentStatus(bool val) 
{
    m_utils->log->Log(__FUNCTION__, 
                      1, 
                      LOG(val));

    m_utils->iviOptions->bQueryInstrStatus = val;

    return m_utils->errorManager->ReportError(IVI_SUCCESS);
}


VTEXResult ImpInherentCapabilityDriverOperation::get_Simulate(bool *val)
{
    m_utils->log->Log(__FUNCTION__, 0);

    VTEXResult status = m_state->initialized();

    if( (status >= IVI_SUCCESS) && (NULL == val) )
    {
        status = m_utils->errorManager->queueError(IVI_E_NULL_POINTER, __FUNCTION__, "val");
    }
    else if(status >= IVI_SUCCESS)
    {
        *val = m_utils->simulating();
    }

    return m_utils->errorManager->ReportError(status);
}


VTEXResult ImpInherentCapabilityDriverOperation::put_Simulate(bool val) 
{
    m_utils->log->Log(__FUNCTION__, 
                      1, 
                      LOG(val));

    VTEXResult status = m_state->initialized();
    if(status >= IVI_SUCCESS)
    {
        status = m_utils->setSimulating(val);
    }

    return m_utils->errorManager->ReportError(status);
}



VTEXResult ImpInherentCapabilityDriverOperation::ClearInterchangeWarnings()
{
    m_utils->log->Log(__FUNCTION__, 0);
	VTEXResult status = IVI_SUCCESS;
	// Do nothing.  Do not return "Not supported" error.

    return m_utils->errorManager->ReportError(status);
}


VTEXResult ImpInherentCapabilityDriverOperation::GetNextCoercionRecord(VTEXString* val)
{
    m_utils->log->Log(__FUNCTION__, 0);
	VTEXResult status = IVI_SUCCESS;  	//Do not return "Not supported" error.

	if(NULL == val )
            status = m_utils->errorManager->queueError(IVI_E_NULL_POINTER, __FUNCTION__, "val");
	else  *val = VTEX_STRING("");

    return m_utils->errorManager->ReportError(status);
}

VTEXResult ImpInherentCapabilityDriverOperation::GetNextInterchangeWarning(VTEXString* val)
{
    m_utils->log->Log(__FUNCTION__, 0);
	VTEXResult status = IVI_SUCCESS;  	//Do not return "Not supported" error.

	if(NULL == val )
            status = m_utils->errorManager->queueError(IVI_E_NULL_POINTER, __FUNCTION__, "val");
	else  *val = VTEX_STRING("");

    return m_utils->errorManager->ReportError(status);
}

VTEXResult ImpInherentCapabilityDriverOperation::InvalidateAllAttributes()
{
    m_utils->log->Log(__FUNCTION__, 0);
	VTEXResult status = IVI_SUCCESS;
	// Do nothing.  Do not return "Not supported" error.
    return m_utils->errorManager->ReportError(status);
}

VTEXResult ImpInherentCapabilityDriverOperation::ResetInterchangeCheck()
{
    m_utils->log->Log(__FUNCTION__, 0);
	VTEXResult status = IVI_SUCCESS;
	// Do nothing.  Do not return "Not supported" error.
  m_utils->iviOptions->bInterchangeCheck = false;
    return m_utils->errorManager->ReportError(status);
}

VTEXResult ImpInherentCapabilityDriverOperation::get_LogicalName(VTEXString *val)
{
    m_utils->log->Log(__FUNCTION__, 1, LOG(val));
	VTEXResult status = IVI_SUCCESS;  	//Do not return "Not supported" error.

	if(NULL == val )
            status = m_utils->errorManager->queueError(IVI_E_NULL_POINTER, __FUNCTION__, "val");
	else  *val = VTEX_STRING("");

    return m_utils->errorManager->ReportError(status);
}

VTEXResult ImpInherentCapabilityDriverOperation::get_InterchangeCheck(bool *val)
{
    m_utils->log->Log(__FUNCTION__, 1, LOG(val));
	VTEXResult status = IVI_SUCCESS;  	//Do not return "Not supported" error.

	if(NULL == val )
            status = m_utils->errorManager->queueError(IVI_E_NULL_POINTER, __FUNCTION__, "val");
	  else  *val = m_utils->iviOptions->bInterchangeCheck;

    return m_utils->errorManager->ReportError(status);
}

VTEXResult ImpInherentCapabilityDriverOperation::put_InterchangeCheck(bool val)
{
    m_utils->log->Log(__FUNCTION__, 1, LOG(val));
	VTEXResult status = IVI_SUCCESS;
	// Do nothing.  Do not return "Not supported" error.
    m_utils->iviOptions->bInterchangeCheck = val;
    return m_utils->errorManager->ReportError(status);
}

VTEXResult ImpInherentCapabilityDriverOperation::get_Cache(bool *val)
{
    m_utils->log->Log(__FUNCTION__, 1, LOG(val));
	VTEXResult status = IVI_SUCCESS;  	//Do not return "Not supported" error.

	if(NULL == val )
            status = m_utils->errorManager->queueError(IVI_E_NULL_POINTER, __FUNCTION__, "val");
	else  	*val = m_utils->iviOptions->bCache;

    return m_utils->errorManager->ReportError(status);
}

VTEXResult ImpInherentCapabilityDriverOperation::put_Cache(bool val)
{
    m_utils->log->Log(__FUNCTION__, 1, LOG(val));
	VTEXResult status = IVI_SUCCESS;

	m_utils->iviOptions->bCache = val;

    return m_utils->errorManager->ReportError(status);
}

VTEXResult ImpInherentCapabilityDriverOperation::get_RangeCheck(bool *val)
{
    m_utils->log->Log(__FUNCTION__, 1, LOG(val));
	VTEXResult status = IVI_SUCCESS;  	//Do not return "Not supported" error.

	if(NULL == val )
            status = m_utils->errorManager->queueError(IVI_E_NULL_POINTER, __FUNCTION__, "val");
	else  *val = m_utils->iviOptions->bRangeCheck;

    return m_utils->errorManager->ReportError(status);
}

VTEXResult ImpInherentCapabilityDriverOperation::put_RangeCheck(bool val)
{
    m_utils->log->Log(__FUNCTION__, 1, LOG(val));
	VTEXResult status = IVI_SUCCESS;

	m_utils->iviOptions->bRangeCheck= val;

    return m_utils->errorManager->ReportError(status);
}

VTEXResult ImpInherentCapabilityDriverOperation::get_RecordCoercions(bool *val)
{
    m_utils->log->Log(__FUNCTION__, 1, LOG(val));
	VTEXResult status = IVI_SUCCESS;  	//Do not return "Not supported" error.

	if(NULL == val )
            status = m_utils->errorManager->queueError(IVI_E_NULL_POINTER, __FUNCTION__, "val");
	else  *val = m_utils->iviOptions->bRecordCoercions;

    return m_utils->errorManager->ReportError(status);
}

VTEXResult ImpInherentCapabilityDriverOperation::put_RecordCoercions(bool val)
{
    m_utils->log->Log(__FUNCTION__, 1, LOG(val));

	VTEXResult status = IVI_SUCCESS;

	m_utils->iviOptions->bRecordCoercions = val;

    return m_utils->errorManager->ReportError(status);
}

