/******************************************************************************
 *
 *  .----------------------.	
 *  |==     ==  ======  == |	$Author: benf $
 *  | ==   ==   ======  == |	$Revision: 20610 $ 
 *  |  == ==      ==    == |	$Date: 2010-07-12 17:08:24 -0400 (Mon, 12 Jul 2010) $ 
 *  |   ===       ==    == |	$HeadURL: http://orion/svn/nextgen/branches/64Bit_Driver/software/Instrument_drivers/libVTEX/common/impInherentIdentity.cpp $
 *  |    =        ==    == |	
 *  `----------------------'
 *
 * Copyright 2006 VXI Technology Inc. as an unpublished work.
 * All rights reserved. The information contained herein is confidential
 * property of VXI Technology, Inc. Use, copy, transfer or disclosure
 * of such information is prohibited except by express written agreement
 * with VXI Technology, Inc.
 *
 * PURPOSE:
 *   IVI inherent capabilities Identity interface
 *
 ******************************************************************************/


/*******************
 * System header
 *******************/


/*******************
 * Library header
 *******************/


/*******************
 * Local header
 *******************/
#include "utilsContainer.h"
#include "functionLogging.h"
#include "iviOptions.h"
#include "errorManager.h"
#include "impInherent.h"
#include "state.h"
#include "Platform.h"
#include "Common.h"


/***********************
 * Forward Declarations
 ***********************/


ImpInherentCapabilityIdentity::ImpInherentCapabilityIdentity(UtilsContainer* utils, State* state)
{
    m_utils = utils;
    m_state = state;

    Description.SetAttributes(this,
        &LibInherentCapabilityIdentity::get_Description);
    Revision.SetAttributes(this,
        &LibInherentCapabilityIdentity::get_Revision);
    Vendor.SetAttributes(this,
        &LibInherentCapabilityIdentity::get_Vendor);
    GroupCapabilities.SetAttributes(this,
        &LibInherentCapabilityIdentity::get_GroupCapabilities);
    Identifier.SetAttributes(this,
        &LibInherentCapabilityIdentity::get_Identifier);
    InstrumentFirmwareRevision.SetAttributes(this,
        &LibInherentCapabilityIdentity::get_InstrumentFirmwareRevision);
    InstrumentManufacturer.SetAttributes(this,
        &LibInherentCapabilityIdentity::get_InstrumentManufacturer);
    InstrumentModel.SetAttributes(this,
        &LibInherentCapabilityIdentity::get_InstrumentModel);
    SpecificationMajorVersion.SetAttributes(this,
        &LibInherentCapabilityIdentity::get_SpecificationMajorVersion);
    SpecificationMinorVersion.SetAttributes(this,
        &LibInherentCapabilityIdentity::get_SpecificationMinorVersion);
    SupportedInstrumentModels.SetAttributes(this,
        &LibInherentCapabilityIdentity::get_SupportedInstrumentModels);
}   


ImpInherentCapabilityIdentity::~ImpInherentCapabilityIdentity()
{
}


VTEXString ImpInherentCapabilityIdentity::getDescription()
{
    return VTEX_STRING(VTI_DRIVER_DESCRIPTION);
}

VTEXString ImpInherentCapabilityIdentity::getRevision()
{
#ifdef EX_DISPLAY_VERSION
    return VTEX_STRING(EX_DISPLAY_VERSION);
#else
    return VTEX_STRING("");
#endif
}

VTEXString ImpInherentCapabilityIdentity::getVendor()
{
    return VTEX_STRING(VTI_INSTRUMENTS);
}

VTEXString ImpInherentCapabilityIdentity::getGroupCapabilities()
{
    return VTEX_STRING("");
}

VTEXString ImpInherentCapabilityIdentity::getIdentifier()
{
    return VTEX_STRING("");
}

VTEXString ImpInherentCapabilityIdentity::getInstrumentManufacturer()
{
    return VTEX_STRING("VTI Instruments Corporation");
}

VTEXString ImpInherentCapabilityIdentity::getInstrumentModel(VTEXResult* finalStatus)
{
    VTEXResult status = IVI_SUCCESS;
	  std::vector<int> slots = m_utils->expManager->slots(PLUGIN_TYPE_PLATFORM);
    std::string result = "";
    for(int i = 0; (status >= IVI_SUCCESS) && (i < (int)slots.size()); i++)
    {
        char* tempBuffer = NULL;
        SUBMIT_NORETURN(deviceName(m_utils->expManager->client(), slots.at(i)),
                        deviceName(m_utils->expManager->client(), slots.at(i), &tempBuffer))
        if(NULL == tempBuffer)
        {
               result += "Not available while simulating,";
        }
        else
        {
               result += tempBuffer;
               result += ",";
               exFree(tempBuffer);
        }
    }
    result.erase(result.length());
    *finalStatus = status;
    return VTEX_STRING(result);
}

int32_t ImpInherentCapabilityIdentity::getSpecMajorVersion()
{
    return 0;
}

int32_t ImpInherentCapabilityIdentity::getSpecMinorVersion()
{
    return 0;
}

VTEXString ImpInherentCapabilityIdentity::getSupportedInstruments()
{
    return VTEX_STRING("");
}



VTEXResult ImpInherentCapabilityIdentity::get_Description(VTEXString *val)
{
    m_utils->log->Log(__FUNCTION__, 0);
    
    VTEXResult status = IVI_SUCCESS;

    POINTER_CHECK(val)
    *val = getDescription();

    return m_utils->errorManager->ReportError(status);
}


VTEXResult ImpInherentCapabilityIdentity::get_Revision(VTEXString *val)
{
    m_utils->log->Log(__FUNCTION__, 0);

    VTEXResult status = IVI_SUCCESS;

    POINTER_CHECK(val)
    *val = getRevision();

    return m_utils->errorManager->ReportError(status);
}


VTEXResult ImpInherentCapabilityIdentity::get_Vendor(VTEXString *val)
{
    m_utils->log->Log(__FUNCTION__, 0);

    VTEXResult status = IVI_SUCCESS;

    POINTER_CHECK(val)
    *val = getVendor();
    
    return m_utils->errorManager->ReportError(status);
}


VTEXResult ImpInherentCapabilityIdentity::get_GroupCapabilities(VTEXString *val)
{
    m_utils->log->Log(__FUNCTION__, 0);
    VTEX_START()

    POINTER_CHECK(val)
    *val = getGroupCapabilities();

    return m_utils->errorManager->ReportError(status);
}


VTEXResult ImpInherentCapabilityIdentity::get_Identifier(VTEXString *val)
{
    m_utils->log->Log(__FUNCTION__, 0);

    VTEXResult status = IVI_SUCCESS;

    POINTER_CHECK(val)
    *val = getIdentifier();
    
    return m_utils->errorManager->ReportError(status);
}


VTEXResult ImpInherentCapabilityIdentity::get_InstrumentFirmwareRevision(VTEXString* val)
{    
    m_utils->log->Log(__FUNCTION__, 0);

    VTEX_START()

    POINTER_CHECK(val)
    std::vector<int> slots = m_utils->expManager->slots(PLUGIN_TYPE_PLATFORM);
    for(unsigned int i = 0; (status >= IVI_SUCCESS) && (i < slots.size()); i++)
    {
        char* tempBuffer = NULL;
        SUBMIT_NORETURN(firmwareVersion(m_utils->expManager->client(), slots.at(i)),
                        firmwareVersion(m_utils->expManager->client(), slots.at(i), &tempBuffer))
        
        if(NULL == tempBuffer)
        {
            *val = VTEX_STRING("Not available while simulating");
        }
        else
        {
            *val = VTEX_STRING(tempBuffer);
            exFree(tempBuffer);
        }
    }

    return m_utils->errorManager->ReportError(status);
}


VTEXResult ImpInherentCapabilityIdentity::get_InstrumentManufacturer(VTEXString *val)
{
    m_utils->log->Log(__FUNCTION__, 0);
    VTEX_START()

    POINTER_CHECK(val)
    *val = getInstrumentManufacturer();

    return m_utils->errorManager->ReportError(status);
}

VTEXResult ImpInherentCapabilityIdentity::get_InstrumentModel(VTEXString *val)
{
    m_utils->log->Log(__FUNCTION__, 0);
    VTEX_START()
    
		POINTER_CHECK(val)
    *val = getInstrumentModel(&status);

    return m_utils->errorManager->ReportError(status);
}

VTEXResult ImpInherentCapabilityIdentity::get_SpecificationMajorVersion(int32_t *val)
{
    m_utils->log->Log(__FUNCTION__, 0);
    VTEXResult status = IVI_SUCCESS;

    POINTER_CHECK(val)
    *val = getSpecMajorVersion();

    return m_utils->errorManager->ReportError(status);
}


VTEXResult ImpInherentCapabilityIdentity::get_SpecificationMinorVersion(int32_t *val)
{
    m_utils->log->Log(__FUNCTION__, 0);
    VTEXResult status = IVI_SUCCESS;

    POINTER_CHECK(val)
    *val = getSpecMinorVersion();

    return m_utils->errorManager->ReportError(status);
}

VTEXResult ImpInherentCapabilityIdentity::get_SupportedInstrumentModels(VTEXString *val)
{
    m_utils->log->Log(__FUNCTION__, 0);
    VTEXResult status = IVI_SUCCESS;

    POINTER_CHECK(val)
    *val = getSupportedInstruments();

    return m_utils->errorManager->ReportError(status);
}
